@@ -1,5 +1,5 @@
 package Weather::OpenWeatherMap::Cache;
-$Weather::OpenWeatherMap::Cache::VERSION = '0.005001';
+$Weather::OpenWeatherMap::Cache::VERSION = '0.005002';
 use Carp;
 use strictures 2;
 
@@ -106,16 +106,19 @@ sub cache {
 }
 
 sub is_cached {
-  my ($self, $request) = @_;
-  my $path = $self->make_path($request);
+  my ($self, $obj) = @_;
+  my $path = $self->make_path($obj);
   return unless $path->exists;
-  return if $self->expire($request);
+  return if $self->expire($obj);
   $path
 }
 
 sub retrieve {
   my ($self, $request) = @_;
-
+  # make_path (via is_cached) will handle Result objs transparently also, but
+  # we need a Request so we can reattach it to returned Result later:
+  $request = $request->request
+    if $request->isa('Weather::OpenWeatherMap::Result');
   my $path = $self->is_cached($request);
   return unless $path;
 
