@@ -1,5 +1,5 @@
 package Weather::OpenWeatherMap::Result::Find;
-$Weather::OpenWeatherMap::Result::Find::VERSION = '0.005001';
+$Weather::OpenWeatherMap::Result::Find::VERSION = '0.005002';
 use Carp;
 use strictures 2;
 
@@ -144,6 +144,10 @@ is empty):
     # ...
   }
 
+The number of items to return at a time can be specified:
+
+  my $iter = $result->iter(3);
+
 =head3 search_type
 
 An alias for L</message>.
