@@ -17,6 +17,11 @@ has second => (
   builder => sub { shift->result_obj->as_array->get(1) },
 );
 
+test 'storable' => sub {
+  my ($self) = @_;
+  can_ok $self->result_obj, 'freeze';
+};
+
 test 'identifiers' => sub {
   my ($self) = @_;
 
@@ -102,11 +107,11 @@ test 'conditions' => sub {
 
 test 'precipitation' => sub {
   my ($self) = @_;
-  cmp_ok $self->first->snow, 'eq', '2.077',
+  cmp_ok $self->first->snow, 'eq', '2.1',
     'snow ok';
   cmp_ok $self->first->rain, '==', 0,
     'rain (default) ok';
-  cmp_ok $self->second->rain, 'eq', '0.0575',
+  cmp_ok $self->second->rain, 'eq', '0.1',
     'rain (non-default) ok';
 };
 
